@@ -8,8 +8,8 @@
  *  This code is distributed under the BSD license, a copy of which is
  *  included in the root directory of this package.
  */
-#ifndef DIALS_ALGORITHMS_IMAGE_THRESHOLD_UNIMODAL_H
-#define DIALS_ALGORITHMS_IMAGE_THRESHOLD_UNIMODAL_H
+#ifndef DIALS_ALGORITHMS_IMAGE_THRESHOLD_LOCAL_H
+#define DIALS_ALGORITHMS_IMAGE_THRESHOLD_LOCAL_H
 
 #include <cmath>
 #include <vector>
@@ -1175,7 +1175,64 @@ namespace dials { namespace algorithms {
     }
 
     /**
-     * Erode the dispersion mask
+     * Erode the dispersion mask: N.B. this inverts the definition in flight -
+     * the purpose of erosion is to extract those pixels which are at least
+     * the kernel-width away from the nearest true background pixel.
+     * The implementation in this context returns the pixels which are
+     * valid for assessing an estimate of the background.
+     *
+     * @param dst The dispersion mask
+     */
+    void erode_dispersion_demo(const af::const_ref<bool, af::c_grid<2> > &mask,
+                               af::ref<bool, af::c_grid<2> > dst) {
+      // array size, slow then fast
+      std::size_t ysize = dst.accessor()[0];
+      std::size_t xsize = dst.accessor()[1];
+
+      // search distance: N.B. that this is in practice one pixel smaller
+      int d = std::min(kernel_size_[0], kernel_size_[1]) - 1;
+
+      // scratch array to store the result, which is then inverted back
+      // to the input array
+      af::versa<bool, af::c_grid<2> > scr(dst.accessor());
+
+      for (int j = 0, k = 0; j < ysize; ++j) {
+        for (std::size_t i = 0; i < xsize; ++i, ++k) {
+          // pixel has to be non-background (dst[k]) and valid (mask[k]) to continue
+          if (!dst[k] || !mask[k]) {
+            scr[k] = false;
+            continue;
+          }
+
+          // take as a prior that this pixel is non-backgroundy
+          bool tmp = true;
+
+          // search over a (2 * d + 1) ** 2 pixel grid for any true background pixel
+          for (int _j = -d; _j <= d; _j++) {
+            if ((j + _j < 0) || (j + _j >= ysize)) continue;
+            for (int _i = -d; _i <= d; _i++) {
+              if ((i + _i < 0 || i + _i >= xsize)) continue;
+              int _k = (j + _j) * xsize + i + _i;
+              if (!dst[_k]) {
+                tmp = false;
+              }
+            }
+          }
+
+          scr[k] = tmp;
+        }
+      }
+
+      // copy mask back, inverting as we go
+      for (int j = 0, k = 0; j < ysize; ++j) {
+        for (std::size_t i = 0; i < xsize; ++i, ++k) {
+          dst[k] = mask[k] && !scr[k];
+        }
+      }
+    }
+
+    /**
+     * Erode the dispersion mask: N.B. this inverts the definition in flight
      * @param dst The dispersion mask
      */
     void erode_dispersion_mask(const af::const_ref<bool, af::c_grid<2> > &mask,
@@ -1377,10 +1434,12 @@ namespace dials { namespace algorithms {
       // above the dispersion threshold
       compute_dispersion_threshold(table, src, mask, dst);
 
-      // Erode the dispersion mask
+      // Erode the dispersion mask: N.B. this changes in place the definition of
+      // dst from "pixels that are not background" to "pixels that are background"
       erode_dispersion_mask(mask, dst);
 
       // Compute the summed area table again now excluding the threshold pixels
+      // (which are set to false in dst)
       compute_sat(table, src, dst);
 
       // Compute the final threshold
@@ -1441,4 +1500,4 @@ namespace dials { namespace algorithms {
 
 }}  // namespace dials::algorithms
 
-#endif /* DIALS_ALGORITHMS_IMAGE_THRESHOLD_UNIMODAL_H */
+#endif /* DIALS_ALGORITHMS_IMAGE_THRESHOLD_LOCAL_H */
