@@ -8,7 +8,7 @@ import pathlib
 import sys
 from dataclasses import dataclass, field
 from multiprocessing import Pool
-from typing import Any, List, Optional, Tuple, Union
+from typing import Any
 
 import numpy as np
 
@@ -33,8 +33,8 @@ class InputToIndex:
     parameters: Any = None
     image_identifier: str = ""
     image_no: int = 0
-    method_list: List[str] = field(default_factory=list)
-    known_crystal_models: Optional[List[Crystal]] = None
+    method_list: list[str] = field(default_factory=list)
+    known_crystal_models: list[Crystal] | None = None
     imageset_no: int = 0
 
 
@@ -45,11 +45,11 @@ class IndexingResult:
     reflection_table: flex.reflection_table = None
     experiments: ExperimentList = None
     n_strong: int = 0
-    n_indexed: List[int] = field(default_factory=list)
-    identifiers: List[str] = field(default_factory=list)
-    rmsd_x: List[float] = field(default_factory=list)
-    rmsd_y: List[float] = field(default_factory=list)
-    rmsd_dpsi: List[float] = field(default_factory=list)
+    n_indexed: list[int] = field(default_factory=list)
+    identifiers: list[str] = field(default_factory=list)
+    rmsd_x: list[float] = field(default_factory=list)
+    rmsd_y: list[float] = field(default_factory=list)
+    rmsd_dpsi: list[float] = field(default_factory=list)
     imageset_no: int = 0
     unindexed_experiment: Experiment = None
 
@@ -66,6 +66,7 @@ loggers_to_disable = [
     "dials.algorithms.indexing.indexer",
     "dials.algorithms.indexing.lattice_search",
     "dials.algorithms.indexing.lattice_search.low_res_spot_match",
+    "dials.algorithms.indexing.lattice_search.ffb_indexer",
 ]
 debug_loggers_to_disable = [
     "dials.algorithms.indexing.symmetry",
@@ -74,7 +75,7 @@ debug_loggers_to_disable = [
 ]
 
 
-class manage_loggers(object):
+class manage_loggers:
     """
     A contextmanager for reducing logging levels for the underlying code of
     parallel ssx programs.
@@ -121,10 +122,10 @@ def index_one(
     experiment: Experiment,
     reflection_table: flex.reflection_table,
     params: phil.scope_extract,
-    method_list: List[str],
+    method_list: list[str],
     image_no: int,
-    known_crystal_models: List[Crystal] = None,
-) -> Union[Tuple[ExperimentList, flex.reflection_table], Tuple[bool, bool]]:
+    known_crystal_models: list[Crystal] = None,
+) -> tuple[ExperimentList, flex.reflection_table] | tuple[bool, bool]:
     elist = ExperimentList([experiment])
     params.indexing.nproc = 1  # make sure none of the processes try to spawn multiprocessing within existing multiprocessing.
     for method in method_list:
@@ -222,10 +223,10 @@ def wrap_index_one(input_to_index: InputToIndex) -> IndexingResult:
 
 def index_all_concurrent(
     experiments: ExperimentList,
-    reflections: List[flex.reflection_table],
+    reflections: list[flex.reflection_table],
     params: phil.scope_extract,
-    method_list: List[str],
-) -> Tuple[ExperimentList, flex.reflection_table, dict]:
+    method_list: list[str],
+) -> tuple[ExperimentList, flex.reflection_table, dict]:
     input_iterable = []
     results_summary = {
         i: [] for i in range(len(experiments))
@@ -272,11 +273,11 @@ def index_all_concurrent(
         ):
             if params.indexing.nproc > 1:
                 with Pool(params.indexing.nproc) as pool:
-                    results: List[IndexingResult] = pool.map(
+                    results: list[IndexingResult] = pool.map(
                         wrap_index_one, input_iterable
                     )
             else:
-                results: List[IndexingResult] = [
+                results: list[IndexingResult] = [
                     wrap_index_one(i) for i in input_iterable
                 ]
 
@@ -292,11 +293,11 @@ def index_all_concurrent(
 
 
 def _join_indexing_results(
-    results: List[IndexingResult],
+    results: list[IndexingResult],
     experiments,
     original_isets,
     identifiers_to_scans,
-) -> Tuple[ExperimentList, flex.reflection_table]:
+) -> tuple[ExperimentList, flex.reflection_table]:
     indexed_experiments = ExperimentList()
     indexed_reflections = flex.reflection_table()
 
@@ -341,7 +342,7 @@ def _join_indexing_results(
 
 
 def _add_results_to_summary_dict(
-    results_summary: dict, results: List[IndexingResult]
+    results_summary: dict, results: list[IndexingResult]
 ) -> dict:
     # convert to results_summary dict current format
     for res in results:
@@ -373,7 +374,7 @@ def preprocess(
     experiments: ExperimentList,
     observed: flex.reflection_table,
     params: phil.scope_extract,
-) -> Tuple[List[flex.reflection_table], phil.scope_extract, List[str]]:
+) -> tuple[list[flex.reflection_table], phil.scope_extract, list[str]]:
     reflections = observed.split_by_experiment_id()
 
     if len(reflections) != len(experiments):
@@ -472,7 +473,7 @@ def index(
     experiments: ExperimentList,
     observed: flex.reflection_table,
     params: phil.scope_extract,
-) -> Tuple[ExperimentList, flex.reflection_table, dict]:
+) -> tuple[ExperimentList, flex.reflection_table, dict]:
     if params.output.nuggets:
         params.output.nuggets = pathlib.Path(
             params.output.nuggets
@@ -483,6 +484,11 @@ def index(
             )
             params.output.nuggets = None
 
+    if any(not s.is_still() for s in experiments.scans()):
+        raise DialsIndexError(
+            "Not all experiments are stills. For rotation data, use the dials.index program."
+        )
+
     reflection_tables, params, method_list = preprocess(experiments, observed, params)
 
     # Do the indexing and generate a summary of results
