@@ -9,6 +9,7 @@ from dxtbx.model.experiment_list import Experiment, ExperimentList
 
 from dials.algorithms.indexing import DialsIndexError, DialsIndexRefineError
 from dials.algorithms.indexing.indexer import Indexer
+from dials.algorithms.indexing.indexer import phil_scope as defaults_phil_scope
 from dials.algorithms.indexing.known_orientation import IndexerKnownOrientation
 from dials.algorithms.indexing.lattice_search import BasisVectorSearch, LatticeSearch
 from dials.algorithms.indexing.nave_parameters import NaveParameters
@@ -64,10 +65,15 @@ def plot_displacements(reflections, predictions, experiments):
 
 def e_refine(params, experiments, reflections, graph_verbose=False):
     # Stills-specific parameters we always want
-    assert params.refinement.reflections.outlier.algorithm in (
-        None,
-        "null",
-    ), "Cannot index, set refinement.reflections.outlier.algorithm=null"  # we do our own outlier rejection
+    assert (
+        params.refinement.reflections.outlier.algorithm
+        in (
+            None,
+            "null",
+        )
+    ), (
+        "Cannot index, set refinement.reflections.outlier.algorithm=null"
+    )  # we do our own outlier rejection
 
     from dials.algorithms.refinement.refiner import RefinerFactory
 
@@ -97,6 +103,7 @@ class StillsIndexer(Indexer):
             # The stills_indexer provides its own outlier rejection
             params.refinement.reflections.outlier.algorithm = "null"
         super().__init__(reflections, experiments, params)
+        self.warn_if_setting_unused_refinement_protocol_params()
 
     def index(self):
         # most of this is the same as dials.algorithms.indexing.indexer.indexer_base.index(), with some stills
@@ -112,9 +119,7 @@ class StillsIndexer(Indexer):
             if max_lattices is not None and len(experiments.crystals()) >= max_lattices:
                 break
             if len(experiments) > 0:
-                cutoff_fraction = (
-                    self.params.multiple_lattice_search.recycle_unindexed_reflections_cutoff
-                )
+                cutoff_fraction = self.params.multiple_lattice_search.recycle_unindexed_reflections_cutoff
                 d_spacings = 1 / self.reflections["rlp"].norms()
                 d_min_indexed = flex.min(d_spacings.select(self.indexed_reflections))
                 min_reflections_for_indexing = cutoff_fraction * len(
@@ -168,7 +173,7 @@ class StillsIndexer(Indexer):
                 )
 
             # discard nearly overlapping lattices on the same shot
-            if self._check_have_similar_crystal_models(experiments):
+            if self._remove_similar_crystal_models(experiments):
                 break
 
             self.indexed_reflections = self.reflections["id"] > -1
@@ -180,7 +185,9 @@ class StillsIndexer(Indexer):
                 isel = (lengths >= self.d_min).iselection()
                 sel.set_selected(isel, True)
                 sel.set_selected(self.reflections["id"] > -1, False)
-            self.unindexed_reflections = self.reflections.select(sel)
+            # N.B. we don't set self.unindexed_reflections here, as we don't want to overwrite yet
+            # if the refinement below fails
+            unindexed_reflections = self.reflections.select(sel)
 
             reflections_for_refinement = self.reflections.select(
                 self.indexed_reflections
@@ -198,9 +205,7 @@ class StillsIndexer(Indexer):
                 # Note, changes to params after initial indexing. Cannot use tie to target when fixing the unit cell.
                 self.all_params.refinement.reflections.outlier.algorithm = "null"
                 self.all_params.refinement.parameterisation.crystal.fix = "cell"
-                self.all_params.refinement.parameterisation.crystal.unit_cell.restraints.tie_to_target = (
-                    []
-                )
+                self.all_params.refinement.parameterisation.crystal.unit_cell.restraints.tie_to_target = []
 
                 for expt_id, experiment in enumerate(experiments):
                     reflections = reflections_for_refinement.select(
@@ -308,7 +313,6 @@ class StillsIndexer(Indexer):
                 reflections_for_refinement = isoform_reflections
 
             if self.params.refinement_protocol.mode == "repredict_only":
-
                 from dials.algorithms.indexing.nave_parameters import NaveParameters
                 from dials.algorithms.refinement.prediction.managed_predictors import (
                     ExperimentsPredictorFactory,
@@ -353,6 +357,9 @@ class StillsIndexer(Indexer):
                 )
 
             else:
+                reflections_for_refinement["_reflection_id"] = flex.size_t(
+                    range(reflections_for_refinement.size())
+                )
                 try:
                     refined_experiments, refined_reflections = self.refine(
                         experiments, reflections_for_refinement
@@ -369,13 +376,40 @@ class StillsIndexer(Indexer):
                     )
                     for model_id in sorted(models_to_remove, reverse=True):
                         del experiments[model_id]
+                    # no need to update self.unindexed_reflections, self.refined_reflections,
+                    # as they hold the state from the previous refinement with one fewer lattice.
                     break
+                else:
+                    # extend the unindexed reflections table with any data that was
+                    # rejected during refinement.
+                    sel = flex.bool(reflections_for_refinement.size(), True)
+                    sel.set_selected(refined_reflections["_reflection_id"], False)
+                    del refined_reflections["_reflection_id"]
+                    del reflections_for_refinement["_reflection_id"]
+                    unindexed_reflections.extend(reflections_for_refinement.select(sel))
 
             self._unit_cell_volume_sanity_check(experiments, refined_experiments)
 
-            self.refined_reflections = refined_reflections.select(
-                refined_reflections["id"] > -1
+            # Processing was successful, so set/update self.refined_reflections, self.unindexed_reflections
+            if -1 in set(refined_reflections["id"]):  # is this ever the case?
+                sel = refined_reflections["id"] < 0
+                refined_reflections.unset_flags(
+                    sel,
+                    refined_reflections.flags.indexed,
+                )
+                refined_reflections["miller_index"].set_selected(sel, (0, 0, 0))
+                unindexed_reflections.extend(refined_reflections.select(sel))
+                refined_reflections.del_selected(sel)
+            self.refined_reflections = refined_reflections
+            unindexed_reflections.unset_flags(
+                flex.bool(unindexed_reflections.size(), True),
+                unindexed_reflections.flags.indexed,
             )
+            unindexed_reflections["id"] = flex.int(unindexed_reflections.size(), -1)
+            unindexed_reflections["miller_index"] = flex.miller_index(
+                unindexed_reflections.size(), (0, 0, 0)
+            )
+            self.unindexed_reflections = unindexed_reflections
 
             for i, expt in enumerate(self.experiments):
                 ref_sel = self.refined_reflections.select(
@@ -433,14 +467,13 @@ class StillsIndexer(Indexer):
         for i, crystal_model in enumerate(self.refined_experiments.crystals()):
             n_indexed = 0
             for _ in experiments.where(crystal=crystal_model):
-                n_indexed += (self.reflections["id"] == i).count(True)
+                n_indexed += (self.refined_reflections["id"] == i).count(True)
             logger.info("model %i (%i reflections):", i + 1, n_indexed)
             logger.info(crystal_model)
 
         if (
             "xyzcal.mm" in self.refined_reflections
         ):  # won't be there if refine_all_candidates = False and no isoforms
-
             self._xyzcal_mm_to_px(self.experiments, self.refined_reflections)
 
     def experiment_list_for_crystal(self, crystal):
@@ -787,6 +820,18 @@ class StillsIndexer(Indexer):
 
         return ref_experiments, reflections
 
+    def warn_if_setting_unused_refinement_protocol_params(self):
+        warning_message = (
+            "Warning: the value of indexing.refinement_protocol.{} has been "
+            "changed to {}, but this parameter is unused by stills indexer."
+        )
+        unused_param_keys = ["n_macro_cycles", "d_min_step", "d_min_final"]
+        defaults = defaults_phil_scope.extract().indexing.refinement_protocol
+        for key in unused_param_keys:
+            value = getattr(self.params.refinement_protocol, key)
+            if value != getattr(defaults, key):
+                logger.warning(warning_message.format(key, str(value)))
+
 
 """Mixin class definitions that override the dials indexing class methods specific to stills"""
 
