@@ -108,7 +108,9 @@ refinement {
 
 }
 
-prediction {
+prediction
+    .expert_level = 1
+{
     d_min = None
         .type = float
 
@@ -211,7 +213,7 @@ class EllipsoidProfileModel(ProfileModelExt):
         return d
 
 
-class ProfileModelBase(object):
+class ProfileModelBase:
     """
     Class to store profile model
 
@@ -724,7 +726,7 @@ class Simple6Angular3ProfileModel(AngularProfileModelBase):
         )
 
 
-class ProfileModelFactory(object):
+class ProfileModelFactory:
     """
     Class to create profile models
 
