@@ -4,7 +4,6 @@ import logging
 import random
 import textwrap
 from math import log, pi, sqrt
-from typing import List
 
 import numpy as np
 from numpy.linalg import det, inv, norm
@@ -76,7 +75,7 @@ def compute_dmbar(S: np.array, dS: np.array, dmu: np.array, epsilon: float) -> n
     return A + B + C + D
 
 
-class ConditionalDistribution(object):
+class ConditionalDistribution:
     """
     A class to compute useful stuff about the conditional distribution
 
@@ -131,7 +130,7 @@ class ConditionalDistribution(object):
         """
         return self._Sbar
 
-    def first_derivatives_of_sigma(self) -> List[np.array]:
+    def first_derivatives_of_sigma(self) -> list[np.array]:
         """
         Return the marginal first derivatives (as a list of 2x2 arrays)
 
@@ -144,7 +143,7 @@ class ConditionalDistribution(object):
 
         return self.dSbar
 
-    def first_derivatives_of_mean(self) -> List[np.array]:
+    def first_derivatives_of_mean(self) -> list[np.array]:
         """
         Return the marginal first derivatives (a list of 2x1 arrays)
 
@@ -174,7 +173,7 @@ def rotate_mat3_double(R, A):
     return np.einsum("ij,jkv,kl->ilv", R, A, R.T)
 
 
-class ReflectionLikelihood(object):
+class ReflectionLikelihood:
     def __init__(self, model, s0, sp, h, ctot, mobs, sobs, panel_id=0):
         # Save stuff
         modelstate = ReflectionModelState(model, s0, h)
@@ -389,7 +388,7 @@ class ReflectionLikelihood(object):
         return I
 
 
-class MaximumLikelihoodTarget(object):
+class MaximumLikelihoodTarget:
     def __init__(
         self, model, s0, sp_list, h_list, ctot_list, mobs_list, sobs_list, panel_ids
     ):
@@ -539,7 +538,7 @@ def gradient_descent(f, df, x0, max_iter=1000, tolerance=1e-10):
     return x
 
 
-class FisherScoringMaximumLikelihoodBase(object):
+class FisherScoringMaximumLikelihoodBase:
     """
     A class to solve maximum likelihood equations using fisher scoring
 
@@ -686,7 +685,7 @@ class FisherScoringMaximumLikelihood(FisherScoringMaximumLikelihoodBase):
 
         """
         # Initialise the super class
-        super(FisherScoringMaximumLikelihood, self).__init__(
+        super().__init__(
             model.active_parameters,
             max_iter=max_iter,
             tolerance=tolerance,
@@ -876,7 +875,7 @@ class FisherScoringMaximumLikelihood(FisherScoringMaximumLikelihoodBase):
                     "",
                     "  R.M.S.D (local) = %.5g" % sqrt(mse),
                     "",
-                    "  R.M.S.D (pixel): X = %.3f, Y = %.3f" % tuple(rmsd),
+                    "  R.M.S.D (pixel): X = {:.3f}, Y = {:.3f}".format(*tuple(rmsd)),
                 ]
             )
         )
@@ -894,7 +893,7 @@ class FisherScoringMaximumLikelihood(FisherScoringMaximumLikelihoodBase):
         )
 
 
-class Refiner(object):
+class Refiner:
     """
     High level profile refiner class that handles book keeping etc
 
@@ -1011,7 +1010,7 @@ class Refiner(object):
         return self.state.parameter_labels
 
 
-class RefinerData(object):
+class RefinerData:
     """
     A class for holding the data needed for the profile refinement
 
@@ -1084,9 +1083,7 @@ class RefinerData(object):
 
         # Print some information
         logger.info("")
-        logger.info(
-            "I_min = %.2f, I_max = %.2f" % (np.min(ctot_list), np.max(ctot_list))
-        )
+        logger.info(f"I_min = {np.min(ctot_list):.2f}, I_max = {np.max(ctot_list):.2f}")
 
         # Sometimes a single reflection might have an enormouse intensity for
         # whatever reason and since we weight by intensity, this can cause the
@@ -1228,7 +1225,7 @@ def print_matrix_np(A, fmt="%.3g", indent=0):
         line = ""
         for i in range(A.shape[1]):
             line += fmt % t[i + j * A.shape[1]]
-        lines.append("%s|%s|" % (prefix, line))
+        lines.append(f"{prefix}|{line}|")
     return "\n".join(lines)
 
 
@@ -1247,5 +1244,5 @@ def print_matrix(A, fmt="%.3g", indent=0):
         line = ""
         for i in range(A.n[1]):
             line += fmt % t[i + j * A.n[1]]
-        lines.append("%s|%s|" % (prefix, line))
+        lines.append(f"{prefix}|{line}|")
     return "\n".join(lines)
