@@ -15,7 +15,6 @@ import logging
 import math
 from copy import deepcopy
 from dataclasses import dataclass
-from typing import List, Tuple
 from unittest.mock import Mock
 
 import numpy as np
@@ -485,7 +484,7 @@ class ExtendedDatasetStatistics(iotbx.merging_statistics.dataset_statistics):
     @classmethod
     def weighted_cchalf(
         cls, this, other, assume_index_matching=False, use_binning=False
-    ) -> List[Tuple]:
+    ) -> list[tuple]:
         if not use_binning:
             assert other.indices().size() == this.indices().size()
             if this.data().size() == 0:
@@ -545,6 +544,7 @@ def merging_stats_from_scaled_array(
     use_internal_variance=False,
     anomalous=True,
     additional_stats=False,
+    cc_one_half_significance_level=0.01,
 ):
     """Calculate the normal and anomalous merging statistics."""
 
@@ -561,7 +561,7 @@ def merging_stats_from_scaled_array(
             sigma_filtering=None,
             eliminate_sys_absent=False,
             use_internal_variance=use_internal_variance,
-            cc_one_half_significance_level=0.01,
+            cc_one_half_significance_level=cc_one_half_significance_level,
             additional_stats=additional_stats,
         )
     except (RuntimeError, Sorry) as e:
@@ -588,7 +588,7 @@ def merging_stats_from_scaled_array(
                     n_bins=n_bins,
                     anomalous=True,
                     sigma_filtering=None,
-                    cc_one_half_significance_level=0.01,
+                    cc_one_half_significance_level=cc_one_half_significance_level,
                     eliminate_sys_absent=False,
                     use_internal_variance=use_internal_variance,
                     additional_stats=additional_stats,
