@@ -97,6 +97,10 @@ class cosym(Subject):
             params = phil_scope.extract()
         self.params = params
 
+        # if all datasets have been through scaling, a decision about error models has
+        # been made, so don't apply any further sigma correction
+        apply_sigma_correction = not all(s for s in experiments.scaling_models())
+
         reference_intensities = None
         if self.params.reference:
             wl = np.mean([expt.beam.get_wavelength() for expt in experiments])
@@ -191,10 +195,15 @@ class cosym(Subject):
             # The purpose of the reference is to help the clustering, not guarantee the indexing solution.
             datasets.append(reference_intensities)
             self.cosym_analysis = CosymAnalysis(
-                datasets, self.params, seed_dataset=len(datasets) - 1
+                datasets,
+                self.params,
+                seed_dataset=len(datasets) - 1,
+                apply_sigma_correction=apply_sigma_correction,
             )
         else:
-            self.cosym_analysis = CosymAnalysis(datasets, self.params)
+            self.cosym_analysis = CosymAnalysis(
+                datasets, self.params, apply_sigma_correction=apply_sigma_correction
+            )
 
     @property
     def experiments(self):
@@ -444,8 +453,7 @@ def run(args=None):
     reflections = parse_multiple_datasets(reflections)
     if len(experiments) != len(reflections):
         raise Sorry(
-            "Mismatched number of experiments and reflection tables found: %s & %s."
-            % (len(experiments), len(reflections))
+            f"Mismatched number of experiments and reflection tables found: {len(experiments)} & {len(reflections)}."
         )
     if len(experiments) == 1:
         raise Sorry(
