@@ -115,6 +115,10 @@ phil_scope = libtbx.phil.parse(
       .help = "A directory with images"
       .multiple = True
 
+    split = None
+      .type = ints
+      .help = "Scan split: either frames_per_block or 1-indexed start,end,frames_per_block"
+
     reference_geometry = None
       .type = path
       .help = "Experimental geometry from this models.expt "
@@ -885,6 +889,41 @@ def do_import(
     metadata_updater = MetaDataUpdater(params)
     experiments = metadata_updater(imagesets)
 
+    # If the user has requested splitting, split - these are in human numbers
+    # so need to subtract 1 from start
+    if params.input.split:
+        if len(params.input.split) == 3:
+            split_start, split_end, step = params.input.split
+            split_start -= 1
+        elif len(params.input.split) == 1:
+            split_start = 0
+            split_end = 0
+            step = params.input.split[0]
+        else:
+            sys.exit("split=frames_per_block or split=start,end,frames_per_block")
+
+        new_experiments = ExperimentList()
+        for experiment in experiments:
+            if split_start == 0 and split_end == 0:
+                _split_start, _split_end = experiment.scan.get_image_range()
+                _split_start -= 1
+            else:
+                _split_start = split_start
+                _split_end = split_end
+
+            for chunk_start in range(_split_start, _split_end, step):
+                end = chunk_start + step
+                if end > _split_end:
+                    end = _split_end
+
+                tmp = ExperimentListFactory.from_imageset_and_crystal(
+                    experiment.imageset, crystal=None
+                )[0]
+                tmp.scan = experiment.scan[chunk_start:end]
+                tmp.imageset = experiment.imageset[chunk_start:end]
+                new_experiments.append(tmp)
+        experiments = new_experiments
+
     # Compute some numbers
     num_sweeps = 0
     num_still_sequences = 0
