@@ -10,10 +10,11 @@ from __future__ import annotations
 import functools
 import itertools
 from collections import defaultdict
+from collections.abc import Callable
 from dataclasses import dataclass, field
 from multiprocessing import Pool
 from pathlib import Path
-from typing import Any, Callable, Dict, List, Optional, Tuple, TypedDict
+from typing import Any, TypedDict
 
 import h5py
 import numpy as np
@@ -92,7 +93,7 @@ class ExtractedValues:
     known_size: bool  # does the size of the data match the number of images
 
 
-class MetadataForFile(object):
+class MetadataForFile:
     def __init__(self):
         self.extracted_data = self.extract()
 
@@ -225,10 +226,10 @@ class NameToMetadataDict(dict):
         return ", ".join(f"{key}: {value}" for key, value in self.items())
 
 
-class ParsedGrouping(object):
-    def __init__(self, images: Dict[str, ImageFile], name):
+class ParsedGrouping:
+    def __init__(self, images: dict[str, ImageFile], name):
         self.name = name
-        self._images_to_metadata: Dict[ImageFile, NameToMetadataDict] = {
+        self._images_to_metadata: dict[ImageFile, NameToMetadataDict] = {
             i: NameToMetadataDict() for i in images.values()
         }
         self.tolerances: dict = {}
@@ -298,9 +299,9 @@ Summary of data in ParsedGrouping class
             header += f"  Image: {i}\n    metadata: {v}\n"
         return header
 
-    def extract_data(self) -> Dict[ImageFile, Dict[str, MetadataForFile]]:
+    def extract_data(self) -> dict[ImageFile, dict[str, MetadataForFile]]:
         # Get the metadata relevant for this grouping, keyed by image.
-        relevant_metadata: Dict[ImageFile, Dict[str, MetadataForFile]] = defaultdict(
+        relevant_metadata: dict[ImageFile, dict[str, MetadataForFile]] = defaultdict(
             dict
         )
         for img, meta in self._images_to_metadata.items():  # ImgFile, NameToMetaDict
@@ -309,10 +310,10 @@ Summary of data in ParsedGrouping class
         return relevant_metadata
 
 
-class ParsedYAML(object):
-    def __init__(self, yml_file: Optional[Path] = None, yml_str: Optional[str] = None):
+class ParsedYAML:
+    def __init__(self, yml_file: Path | None = None, yml_str: str | None = None):
         if yml_file:
-            with open(yml_file, "r") as f:
+            with open(yml_file) as f:
                 data = list(yaml.load_all(f, Loader=SafeLoader))[0]
         elif yml_str:
             data = list(yaml.load_all(yml_str, Loader=SafeLoader))[0]
@@ -386,7 +387,7 @@ class ParsedYAML(object):
         return images
 
     @property
-    def groupings(self) -> Dict[str, ParsedGrouping]:
+    def groupings(self) -> dict[str, ParsedGrouping]:
         return self._groupings
 
     def _parse_metadata(self, metadata: dict):
@@ -489,7 +490,7 @@ class ParsedYAML(object):
 
 
 # Class to store metadata group parameters
-class _MetaDataGroup(object):
+class _MetaDataGroup:
     def __init__(self, data_dict):
         self._data_dict: dict[str, dict[str, float]] = data_dict
 
@@ -507,11 +508,11 @@ class _MetaDataGroup(object):
 
 
 # Define mapping from image index to group id.
-class _ImgIdxToGroupId(object):
+class _ImgIdxToGroupId:
     def __init__(
         self,
-        single_return_val: Optional[int] = None,
-        key_to_group_id: Optional[Callable[[int], int]] = None,
+        single_return_val: int | None = None,
+        key_to_group_id: Callable[[int], int] | None = None,
     ):
         self.single_return_val = single_return_val
         self.group_ids: flex.int = flex.int([])
@@ -532,7 +533,7 @@ class _ImgIdxToGroupId(object):
 
 
 class _GroupInfo(TypedDict):
-    group_ids: List[int]
+    group_ids: list[int]
     img_idx_to_group_id: _ImgIdxToGroupId
 
 
@@ -566,7 +567,7 @@ def _determine_groupings(parsed_group: ParsedGrouping):
                         unique_vals.append(tp)
                 unique_values_for_metadata[name] = np.array(unique_vals)
 
-    groups: List[_MetaDataGroup] = []  # list of dicts
+    groups: list[_MetaDataGroup] = []  # list of dicts
     # NB this is not necessarily the number of actual images, in the case
     # that the metadata for a file is only single values rather than arrays.
     n_images = sum(n_images_per_file.values())
@@ -604,9 +605,9 @@ def _determine_groupings(parsed_group: ParsedGrouping):
 
 
 @dataclass
-class GroupsForExpt(object):
-    single_group: Optional[int] = None
-    groups_array: Optional[np.array] = None
+class GroupsForExpt:
+    single_group: int | None = None
+    groups_array: np.array | None = None
     unique_group_numbers: set = field(default_factory=set)
 
 
@@ -633,17 +634,17 @@ class FilePair:
 
 
 @dataclass
-class SplittingIterable(object):
+class SplittingIterable:
     working_directory: Path
     fp: FilePair
     fileindex: int
     groupindex: int
     groupdata: GroupsForExpt
     name: str
-    params: Optional[Any] = None
+    params: Any | None = None
 
 
-def save_subset(input_: SplittingIterable) -> Optional[Tuple[str, FilePair]]:
+def save_subset(input_: SplittingIterable) -> tuple[str, FilePair] | None:
     expts = load.experiment_list(input_.fp.expt, check_format=False)
     refls = flex.reflection_table.from_file(input_.fp.refl)
     groupdata = input_.groupdata
@@ -674,7 +675,7 @@ def save_subset(input_: SplittingIterable) -> Optional[Tuple[str, FilePair]]:
     return None
 
 
-class GroupingImageTemplates(object):
+class GroupingImageTemplates:
     """Class that takes a parsed group and determines the groupings and mappings
     required to split input data into groups.
 
@@ -693,8 +694,8 @@ class GroupingImageTemplates(object):
 
     @staticmethod
     def _files_to_groups(
-        metadata: Dict[ImageFile, Dict[str, MetadataForFile]],
-        groups: List[_MetaDataGroup],
+        metadata: dict[ImageFile, dict[str, MetadataForFile]],
+        groups: list[_MetaDataGroup],
     ) -> dict[ImageFile, _GroupInfo]:
         # Ok now we have the groupings of the metadata. Now find which groups each
         # file contains.
@@ -740,8 +741,8 @@ class GroupingImageTemplates(object):
 
         return file_to_groups
 
-    def _get_expt_file_to_groupsdata(self, data_file_pairs: List[FilePair]):
-        expt_file_to_groupsdata: Dict[Path, GroupsForExpt] = {}
+    def _get_expt_file_to_groupsdata(self, data_file_pairs: list[FilePair]):
+        expt_file_to_groupsdata: dict[Path, GroupsForExpt] = {}
 
         for fp in data_file_pairs:
             expts = load.experiment_list(fp.expt, check_format=False)
@@ -808,9 +809,9 @@ class GroupingImageTemplates(object):
             expt_file_to_groupsdata[fp.expt] = groupdata
         return expt_file_to_groupsdata
 
-    def write_groupids_into_files(self, data_file_pairs: List[FilePair]) -> None:
+    def write_groupids_into_files(self, data_file_pairs: list[FilePair]) -> None:
         "Write a group_id column into the reflection table"
-        expt_file_to_groupsdata: Dict[Path, GroupsForExpt] = (
+        expt_file_to_groupsdata: dict[Path, GroupsForExpt] = (
             self._get_expt_file_to_groupsdata(data_file_pairs)
         )
 
@@ -826,7 +827,7 @@ class GroupingImageTemplates(object):
                 refls["group_id"] = flex.int(refls.size(), group_id)
             else:
                 identifiers_map = refls.experiment_identifiers()
-                list_of_identifiers: List = list(expts.identifiers())
+                list_of_identifiers: list = list(expts.identifiers())
                 groups_array = flumpy.from_numpy(groupdata.groups_array)
 
                 def table_id_to_group_id(table_id):
@@ -846,14 +847,14 @@ class GroupingImageTemplates(object):
     def split_files_to_groups(
         self,
         working_directory: Path,
-        data_file_pairs: List[FilePair],
+        data_file_pairs: list[FilePair],
         function_to_apply: Callable[
-            [SplittingIterable], Optional[Tuple[str, FilePair]]
+            [SplittingIterable], tuple[str, FilePair] | None
         ] = save_subset,
         params: Any = None,
         prefix: str = "",
     ):
-        expt_file_to_groupsdata: Dict[Path, GroupsForExpt] = (
+        expt_file_to_groupsdata: dict[Path, GroupsForExpt] = (
             self._get_expt_file_to_groupsdata(data_file_pairs)
         )
         template = "{name}group_{index:0{maxindexlength:d}d}"
@@ -863,10 +864,10 @@ class GroupingImageTemplates(object):
             maxindexlength=len(str(len(self._groups))),
         )
 
-        names: List[str] = [
+        names: list[str] = [
             name_template(index=i + 1) for i, _ in enumerate(self._groups)
         ]
-        filesdict: dict[str, List[FilePair]] = {name: [] for name in names}
+        filesdict: dict[str, list[FilePair]] = {name: [] for name in names}
 
         input_iterable = []
         for groupindex, name in enumerate(names):
@@ -902,8 +903,8 @@ class GroupingImageFiles(GroupingImageTemplates):
 
     @staticmethod
     def _files_to_groups(
-        metadata: Dict[ImageFile, Dict[str, MetadataForFile]],
-        groups: List[_MetaDataGroup],
+        metadata: dict[ImageFile, dict[str, MetadataForFile]],
+        groups: list[_MetaDataGroup],
     ) -> dict[ImageFile, _GroupInfo]:
         # Ok now we have the groupings of the metadata. Now find which groups each
         # file contains.
@@ -972,8 +973,8 @@ class GroupingImageFiles(GroupingImageTemplates):
 
         return file_to_groups
 
-    def _get_expt_file_to_groupsdata(self, data_file_pairs: List[FilePair]):
-        expt_file_to_groupsdata: Dict[Path, GroupsForExpt] = {}
+    def _get_expt_file_to_groupsdata(self, data_file_pairs: list[FilePair]):
+        expt_file_to_groupsdata: dict[Path, GroupsForExpt] = {}
 
         for fp in data_file_pairs:
             expts = load.experiment_list(fp.expt, check_format=False)
@@ -1037,7 +1038,7 @@ def get_grouping_handler(parsed: ParsedYAML, grouping: str, nproc: int = 1):
 
 
 def series_repeat_to_groupings(
-    experiments: List[ExperimentList], series_repeat: int, groupname="split_by"
+    experiments: list[ExperimentList], series_repeat: int, groupname="split_by"
 ) -> ParsedYAML:
     """
     For a dose series data collection, attempt to create and then parse a
