@@ -6,7 +6,6 @@ import math
 import sys
 import time
 from collections import namedtuple
-from typing import Tuple
 
 import libtbx.phil
 from cctbx import crystal
@@ -203,7 +202,7 @@ def _apply_resolution_mask(mask, beam, panel, *args):
 
 def generate_mask(
     imageset: ImageSet, params: libtbx.phil.scope_extract
-) -> Tuple[flex.bool]:
+) -> tuple[flex.bool]:
     """Generate a mask based on the input parameters.
 
     Args:
