@@ -38,8 +38,8 @@ def test_dials_cluster_unit_cell_command_line_output_files(dials_data, tmp_path)
 
     # Combine experiments. Write PHIL file to avoid "command line is too long" error on Windows
     with open(tmp_path / "input.phil", "w") as f:
-        f.writelines((f"input.reflections={i}" + os.linesep for i in reflections))
-        f.writelines((f"input.experiments={i}" + os.linesep for i in experiments))
+        f.writelines(f"input.reflections={i}" + os.linesep for i in reflections)
+        f.writelines(f"input.experiments={i}" + os.linesep for i in experiments)
     result = subprocess.run(
         [shutil.which("dials.combine_experiments"), "input.phil"],
         cwd=tmp_path,
@@ -92,8 +92,8 @@ def test_dials_cluster_unit_cell_command_line_output_files(dials_data, tmp_path)
 
     # Write PHIL file to avoid "command line is too long" error on Windows
     with open(tmp_path / "input.phil", "w") as f:
-        f.writelines((f"input.reflections={i}" + os.linesep for i in reflections))
-        f.writelines((f"input.experiments={i}" + os.linesep for i in experiments))
+        f.writelines(f"input.reflections={i}" + os.linesep for i in reflections)
+        f.writelines(f"input.experiments={i}" + os.linesep for i in experiments)
     result = subprocess.run(
         [
             shutil.which("dials.cluster_unit_cell"),
